pub enum PerformancePriority {
HighSpeed,
Balanced,
LowMemory,
}Expand description
This enum can be supplied to the FmIndexConfig to select different sub-algorithms during the
construction of the FM-Index.
The default is HighSpeed.
Variants
HighSpeed
Balanced
For alphabets with 16 or less symbols in dense encoding, the temporary concatenated text and the BWT buffer can be compressed to use less memory while constructing the BWT. This reduces the peak memory usage of the construction by about 10-15% and only takes a small amount of additional running time.
LowMemory
In addition to the space improvements of the Balanced variant, a much slower, not parallel suffix
array construction algorithm will be used for u32-based FM-Indices.
This only happens if the u32-saca feature is activated (by default it is).
This can save a lot of memory when the sum of text lengths fits into a u32, but not into a i32.
The downside is that the construction is much slower (at least 5 times slower should be expected).